package com.bonus.material.repair.service;

import java.util.List;
import com.bonus.material.repair.domain.RepairApplyRecord;

/**
 * 维修记录Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface IRepairApplyRecordService {
    /**
     * 查询维修记录
     * 
     * @param id 维修记录主键
     * @return 维修记录
     */
    public RepairApplyRecord selectRepairApplyRecordById(Long id);

    /**
     * 查询维修记录列表
     * 
     * @param repairApplyRecord 维修记录
     * @return 维修记录集合
     */
    public List<RepairApplyRecord> selectRepairApplyRecordList(RepairApplyRecord repairApplyRecord);

    /**
     * 新增维修记录
     * 
     * @param repairApplyRecord 维修记录
     * @return 结果
     */
    public int insertRepairApplyRecord(RepairApplyRecord repairApplyRecord);

    /**
     * 修改维修记录
     * 
     * @param repairApplyRecord 维修记录
     * @return 结果
     */
    public int updateRepairApplyRecord(RepairApplyRecord repairApplyRecord);

    /**
     * 批量删除维修记录
     * 
     * @param ids 需要删除的维修记录主键集合
     * @return 结果
     */
    public int deleteRepairApplyRecordByIds(Long[] ids);

    /**
     * 删除维修记录信息
     * 
     * @param id 维修记录主键
     * @return 结果
     */
    public int deleteRepairApplyRecordById(Long id);
}
