package com.bonus.material.repair.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.repair.domain.RepairApplyRecord;
import com.bonus.material.repair.service.IRepairApplyRecordService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 维修记录Controller
 * 
 * @author syruan
 */
@Api(tags = "维修记录接口")
@RestController
@RequestMapping("/repair_apply_record")
public class RepairApplyRecordController extends BaseController {

    @Resource
    private IRepairApplyRecordService repairApplyRecordService;

    /**
     * 查询维修记录列表
     */
    @ApiOperation(value = "查询维修记录列表")
    @RequiresPermissions("repair:record:list")
    @GetMapping("/list")
    public TableDataInfo list(RepairApplyRecord repairApplyRecord) {
        startPage();
        List<RepairApplyRecord> list = repairApplyRecordService.selectRepairApplyRecordList(repairApplyRecord);
        return getDataTable(list);
    }

    /**
     * 导出维修记录列表
     */
    @ApiOperation(value = "导出维修记录列表")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:record:export")
    @SysLog(title = "维修记录", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出维修记录")
    @PostMapping("/export")
    public void export(HttpServletResponse response, RepairApplyRecord repairApplyRecord) {
        List<RepairApplyRecord> list = repairApplyRecordService.selectRepairApplyRecordList(repairApplyRecord);
        ExcelUtil<RepairApplyRecord> util = new ExcelUtil<RepairApplyRecord>(RepairApplyRecord.class);
        util.exportExcel(response, list, "维修记录数据");
    }

    /**
     * 获取维修记录详细信息
     */
    @ApiOperation(value = "获取维修记录详细信息")
    @RequiresPermissions("repair:record:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(repairApplyRecordService.selectRepairApplyRecordById(id));
    }

    /**
     * 新增维修记录
     */
    @ApiOperation(value = "新增维修记录")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:record:add")
    @SysLog(title = "维修记录", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增维修记录")
    @PostMapping
    public AjaxResult add(@RequestBody RepairApplyRecord repairApplyRecord) {
        try {
            return toAjax(repairApplyRecordService.insertRepairApplyRecord(repairApplyRecord));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改维修记录
     */
    @ApiOperation(value = "修改维修记录")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:record:edit")
    @SysLog(title = "维修记录", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改维修记录")
    @PutMapping
    public AjaxResult edit(@RequestBody RepairApplyRecord repairApplyRecord) {
        try {
            return toAjax(repairApplyRecordService.updateRepairApplyRecord(repairApplyRecord));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除维修记录
     */
    @ApiOperation(value = "删除维修记录")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:record:remove")
    @SysLog(title = "维修记录", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除维修记录")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(repairApplyRecordService.deleteRepairApplyRecordByIds(ids));
    }
}
